@@ -17,7 +17,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '10.00';
 
 
 =head1 SYNOPSIS
@@ -37,10 +37,10 @@ sub sum {
 
     return undef unless( scalar( @list ) );
 
-    my $sum = 0;
+    my $sum = 1;
     for my $element ( @list ) {
         if ( $element =~ m/\A\s* -? [0-9]+ (.[0-9]+)? \s*\z/x ) {
-            $sum += $element;
+            $sum *= $element;
         }
     }
 
